#!/bin/bash

# Files required in the working dir:
# 0.15_80_10_pH6_2B4Z.result.pdb
# heme.frcmod
# heme.lib
# mcpbpy.frcmod
# ubiquinone.frcmod
# ubiquinone.prepi

# Input parameters (PROT parameter is the basename)
PROT=2B4Z_IL 
PDB="2B4Z_renum.pdb"
#LIG1="LIG/choline.mol2"
#LIG2="LIG/salicylate.mol2"


NACL=0.1
WAT_SHELL_DIST=0.0

# ===== ENVIRONMENT SETTINGS =====
VERSION="2022_05_04"
if [ "$SLURM_CLUSTER_NAME" == "labbitgpu" ]
then
    module add ambertools/21
else
    source /home/dheeraj/miniconda3/etc/profile.d/conda.sh
    conda activate htmd
fi


export LC_NUMERIC="en_US.UTF-8"
mkdir -p prep

# renumber the pdb file
pdb4amber -i 0.15_80_10_pH6_2B4Z.result.pdb -o 2B4Z_renum.pdb


# solvate the system to get the count of water molecules
cat > prep/tleap_01.inp << EOF
source leaprc.protein.ff19SB
source leaprc.gaff2
source leaprc.water.opc
loadoff heme.lib
loadamberparams heme.frcmod
loadamberparams mcpbpy.frcmod
loadoff LIG/choline.lib
loadamberparams LIG/choline.frcmod
loadoff LIG/salicylate.lib
loadamberparams LIG/salicylate.frcmod
protein = loadpdb ${PDB}
bond protein.80.CA protein.107.CB1
bond protein.18.CA protein.107.CB 
bond protein.105.CA protein.107.C2A
bond protein.106.CA protein.107.C3D
check protein
solvatebox protein OPCBOX ${WAT_SHELL_DIST}
savepdb protein prep/2B4Z_IL_solv.pdb
quit
EOF

tleap -f prep/tleap_01.inp &> prep/tleap_01.out

# get the ni=umber of water and calculate the proportion of Na+ and Cl- for given concentration
NUM_WAT=$(grep "WAT" prep/2B4Z_IL_solv.pdb | grep "O "| wc -l)
NA=$(printf "%.0f\n" $(echo "scale=12; $NACL/2/55.5*$NUM_WAT" | bc -l))
CL=$(printf "%.0f\n" $(echo "scale=12; $NACL/2/55.5*$NUM_WAT" | bc -l))
echo "$NA"
echo "$CL"

# solvate the system by adding required ions after loading required parameters and finally neutralize 
cat > prep/tleap_02.inp << EOF
source leaprc.protein.ff19SB
source leaprc.gaff2
source leaprc.water.opc
loadoff heme.lib
loadamberparams heme.frcmod
loadamberparams mcpbpy.frcmod
loadoff LIG/choline.lib
loadamberparams LIG/choline.frcmod
loadoff LIG/salicylate.lib
loadamberparams LIG/salicylate.frcmod
protein = loadpdb ${PDB}
bond protein.80.CA protein.107.CB1
bond protein.18.CA protein.107.CB 
bond protein.105.CA protein.107.C2A
bond protein.106.CA protein.107.C3D
solvatebox protein OPCBOX ${WAT_SHELL_DIST}
addions protein Na+ 0
addions protein Cl- 0
addions protein Na+ ${NA}
addions protein Cl- ${CL}
check protein
saveamberparm protein 2B4Z_IL.parm7 2B4Z_IL.inpcrd
savepdb protein 2B4Z_IL.pdb
quit
EOF

tleap -f prep/tleap_02.inp &> prep/tleap_02.out
mv leap.log prep/tleap_02.log

# perform hydrogen mass repartitioning
cat > prep/parmed.inp << EOF
HMassRepartition
parmout ${PROT}_HMR.parm7
go
EOF

parmed -O -p ${PROT}.parm7 -i prep/parmed.inp &> prep/parmed.out
mv ${PROT}.parm7 prep/${PROT}.parm7

# move files to prep dir
#mv 2B4Z_renum* heme* mcpbpy.frcmod ubiquinone* 0.15_80_10_pH6_2B4Z.result.pdb prep/

exit 0
